show.c

LISP Interpreter Run

[[[
 Show that a formal system of complexity N
 can't prove that a specific object has
 complexity > N + 1127.
 Formal system is a never halting lisp expression
 that displays pairs (lisp object, lower bound
 on its complexity).  E.g., (x(1111)) means
 that x has complexity H(x) greater than or equal to 4.
]]]

[ (<xy) tells if x is less than y ]
& (<xy) /.y0 /.x1 (<-x-y)

<:          (&(xy)(/(.y)0(/(.x)1(<(-x)(-y)))))

(<'(11)'(11))

expression  (<('(11))('(11)))
value       0

(<'(11)'(111))

expression  (<('(11))('(111)))
value       1

(<'(111)'(11))

expression  (<('(111))('(11)))
value       0


[ Search list p for first s in pair (s,m) with H(s) >= m > n ]
[ (Returns 0/false to indicate not found.) ]
& (Epn) /.p 0 /(<n+-+p) ++p (E-pn)

E:          (&(pn)(/(.p)0(/(<n(+(-(+p))))(+(+p))(E(-p)n))))

(E'((x(11))(y(111)))'())

expression  (E('((x(11))(y(111))))('()))
value       x

(E'((x(11))(y(111)))'(1))

expression  (E('((x(11))(y(111))))('(1)))
value       x

(E'((x(11))(y(111)))'(11))

expression  (E('((x(11))(y(111))))('(11)))
value       y

(E'((x(11))(y(111)))'(111))

expression  (E('((x(11))(y(111))))('(111)))
value       0

(E'((x(11))(y(111)))'(1111))

expression  (E('((x(11))(y(111))))('(1111)))
value       0


++?0'!%  [[Universal binary computer U]]
         [[Put together program for U:]]
^#~'     [[Show crucial prefix so can size it]]
"(       [[begin literally]]

[ (<xy) tells if x is less than y ]
: (<xy) /.y0 /.x1 (<-x-y)    [[ CORRECT DEFINITION!!! ]]

[ Search list p for first s in pair (s,m) with H(s) >= m > n ]
[ (Returns 0/false to indicate not found.) ]
: (Epn) /.p 0 /(<n+-+p) ++p (E-pn)

[ (2n) = convert reversed binary to unary ]
: (2n) /.n() :k(2-n) /+n *1^kk ^kk

[ k is the size in bits of this program for U, ]
[ excluding the bits in the formal axiomatic system. ]
: k (2'(111 001 100 01)) [k = 1127 base 10 = 2147 base 8]

[Main Loop - t is depth limit (time),
             b is bits of FAS read so far (buffer)]
: (Ltb)
 : v ?t'!%b [run FAS for time t]
 : s (E-v^kb) [look for s-exp s that is proved to have complexity H(s)
               > 1127 + # of bits of FAS read]
 /s s       [Found it!  Output it and halt]
            [Contradiction: our value has complexity
             greater than our size!]
            [Our size is 1127 bits + the number of bits of
             the FAS that were read at the point that the
             search succeeded (some bits of the FAS may be
             unread).]
 /="!+v  (Lt^b*@()) [Read another bit of FAS]
 /="?+v  (L*1tb)    [Increase depth/time limit]
 "?     [Surprise, formal system halts, so we do too]

(L()())    [Initially, 0 depth limit and no bits read]

 )      [[end literally]]

#'
"(      [[begin literally]]

[[This is the FAS]]
,'((xy)(11))  [FAS = {"H((xy)) >= 2"}]

 )      [[end literally]]

expression  (+(+(?0('(!(%)))(^(#(~('(:(<xy)/.y0/.x1(<-x-y):(Ep
            n)/.p0/(<n+-+p)++p(E-pn):(2n)/.n():k(2-n)/+n*1^kk^
            kk:k(2'(11100110001)):(Ltb):v?t'!%b:s(E-v^kb)/ss/=
            "!+v(Lt^b*@())/="?+v(L*1tb)"?(L()())))))(#('(,'((x
            y)(11)))))))))
show        (:(<xy)/.y0/.x1(<-x-y):(Epn)/.p0/(<n+-+p)++p(E-pn)
            :(2n)/.n():k(2-n)/+n*1^kk^kk:k(2'(11100110001)):(L
            tb):v?t'!%b:s(E-v^kb)/ss/="!+v(Lt^b*@())/="?+v(L*1
            tb)"?(L()()))
size        161(241)/1127(2147)
value       ?

End of LISP Run

Elapsed time is 0 seconds.
