show.c

LISP Interpreter Run

[[[
 Show that a formal system of complexity N
 can't determine more than N + 3689 bits of Omega.
 Formal system is a never halting lisp expression
 that displays lists of the form (10X0XXXX10).
 This stands for the fractional part of Omega,
 and means that these 0,1 bits of Omega are known.
 X stands for an unknown bit.
]]]

[Count number of bits in an omega that are determined.]
& (Cw) /.w() /=X+w (C-w) *1(C-w)

C:          (&(w)(/(.w)()(/(=X(+w))(C(-w))(*1(C(-w))))))

(C'(XXX))

expression  (C('(XXX)))
value       ()

(C'(1XX))

expression  (C('(1XX)))
value       (1)

(C'(1X0))

expression  (C('(1X0)))
value       (11)

(C'(110))

expression  (C('(110)))
value       (111)


[Merge bits of data into unknown bits of an omega.]
& (Mw) /.w() * /=X+w@+w (M-w)

M:          (&(w)(/(.w)()(*(/(=X(+w))(@)(+w))(M(-w)))))

[Test it.]
++?0 ':(Mw)/.w()*/=X+w@+w(M-w) (M'(00X00X00X)) '(111)

expression  (+(+(?0('(('(&(M)(M('(00X00X00X)))))('(&(w)(/(.w)(
            )(*(/(=X(+w))(@)(+w))(M(-w))))))))('(111)))))
value       (001001001)

++?0 ':(Mw)/.w()*/=X+w@+w(M-w) (M'(11X11X111)) '(00)

expression  (+(+(?0('(('(&(M)(M('(11X11X111)))))('(&(w)(/(.w)(
            )(*(/(=X(+w))(@)(+w))(M(-w))))))))('(00)))))
value       (110110111)


[(<xy) tells if x is less than y.]
& (<xy) /.y0 /.x1 (<-x-y)

<:          (&(xy)(/(.y)0(/(.x)1(<(-x)(-y)))))

(<'(11)'(11))

expression  (<('(11))('(11)))
value       0

(<'(11)'(111))

expression  (<('(11))('(111)))
value       1

(<'(111)'(11))

expression  (<('(111))('(11)))
value       0


[
 Examine omegas in list w to see if in any one of them
 the number of bits that are determined is greater than n.
 Returns 0 to indicate not found, or what it found.
]
& (Ewn) /.w 0 /(<n(C+w)) +w (E-wn)

E:          (&(wn)(/(.w)0(/(<n(C(+w)))(+w)(E(-w)n))))

(E'((00)(000))'())

expression  (E('((00)(000)))('()))
value       (00)

(E'((00)(000))'(1))

expression  (E('((00)(000)))('(1)))
value       (00)

(E'((00)(000))'(11))

expression  (E('((00)(000)))('(11)))
value       (000)

(E'((00)(000))'(111))

expression  (E('((00)(000)))('(111)))
value       0

(E'((00)(000))'(1111))

expression  (E('((00)(000)))('(1111)))
value       0


++?0'!%  [ The universal computer U ]
         [ Put together program for U : ]

^#~'     [ Show crucial prefix so that we can size it ]
"(       [ begin literally ]

[Count number of bits in an omega that are determined.]
: (Cw) /.w() /=X+w (C-w) *1(C-w)

[Merge bits of data into unknown bits of an omega.]
: (Mw) /.w() * /=X+w@+w (M-w)

[(<xy) tells if x is less than y.]
: (<xy) /.y0 /.x1 (<-x-y)    [[CORRECT DEFINITION OF <]]

[
 Examine omegas in list w to see if in any one of them
 the number of bits that are determined is greater than n.
 Returns 0 to indicate not found, or what it found.
]
: (Ewn) /.w 0 /(<n(C+w)) +w (E-wn)

[ (2n) = convert reverse binary to unary ]
: (2n) /.n() :k(2-n) /+n *1^kk ^kk

[We know that H(Omega sub n) > n - 2177]
[Let k be 2177 plus the size of this program in bits = 2177 + 1512 = 3689]
: k (2'(100 101 100 111))  [ k = 3689 base 10 = 7151 base 8 ]
[
 Size of this program is 1512 + bits of FAS read + missing bits of Omega.
 Program tries to output this many + 2177 bits of Omega.
 But that would give us a program whose output is more complex
 than the size of the program.  Contradiction!
 Thus this program won't find what it is looking for.
 So FAS of complexity N cannot determine > N + 2177 + 1512 bits of Omega,
 i.e., > N + 3689 bits of Omega.
]
[Main Loop: t is depth limit (time),
            b is bits of FAS read so far (buffer).]
: (Ltb)
 :v      ?t'!%b     [Run FAS again.]
 :s      (E-v^kb)   [Look for an omega with >
                     (size of this program + 2177) bits determined.]
 /s      (Ms)       [Found it!  Merge in undetermined bits,
                     output result, and halt.]
 /="!+v  (Lt^b*@()) [Read another bit of FAS.]
 /="?+v  (L*1tb)    [Increase depth/time limit.]
 "?                 [Surprise, formal system halts,
                     so we do too.]

(L()())             [Initially, 0 depth limit
                     and no bits read.]
 )                  [ end literally ]

^#'"(
,'(1X0) [Toy formal system with only one theorem.]
    )

'(0) [Missing bit of omega that is needed.]

expression  (+(+(?0('(!(%)))(^(#(~('(:(Cw)/.w()/=X+w(C-w)*1(C-
            w):(Mw)/.w()*/=X+w@+w(M-w):(<xy)/.y0/.x1(<-x-y):(E
            wn)/.w0/(<n(C+w))+w(E-wn):(2n)/.n():k(2-n)/+n*1^kk
            ^kk:k(2'(100101100111)):(Ltb):v?t'!%b:s(E-v^kb)/s(
            Ms)/="!+v(Lt^b*@())/="?+v(L*1tb)"?(L()())))))(^(#(
            '(,'(1X0))))('(0)))))))
show        (:(Cw)/.w()/=X+w(C-w)*1(C-w):(Mw)/.w()*/=X+w@+w(M-
            w):(<xy)/.y0/.x1(<-x-y):(Ewn)/.w0/(<n(C+w))+w(E-wn
            ):(2n)/.n():k(2-n)/+n*1^kk^kk:k(2'(100101100111)):
            (Ltb):v?t'!%b:s(E-v^kb)/s(Ms)/="!+v(Lt^b*@())/="?+
            v(L*1tb)"?(L()()))
size        216(330)/1512(2750)
value       ?

End of LISP Run

Elapsed time is 1 seconds.
