show.c

LISP Interpreter Run

[[[ Show that a formal system of lisp complexity H_L (FAS) = N
    cannot enable us to exhibit an elegant M-expression of
    size greater than N + 187.
    An elegant lisp M-expression is one with the property that no
    smaller M-expression has the same output.  One may consider
    the output of an M-expression to be either its value or what
    it displays.  The proof below works in either case.
    Setting: formal axiomatic system is never-ending lisp M-expression
    that displays elegant M-expressions.
]]]

[ Idea is to have a program P search for something X that can be proved
  to be more complex than P is, and therefore P can never find X.
  I.e., idea is to show that if this program halts we get a contradiction,
  and therefore the program doesn't halt. ]

[m-expression:]
'"(*a*b*c())

expression  ('(*a*b*c()))
value       (*a*b*c())

[convert m-exp to s-exp]
++?0'%#'"(*a*b*c())

expression  (+(+(?0('(%))(#('(*a*b*c()))))))
value       (*a(*b(*c())))

[convert m-exp to s-exp and run it]
!,++?0'%#'"(*a*b*c())

expression  (!(,(+(+(?0('(%))(#('(*a*b*c()))))))))
display     (*a(*b(*c())))
value       (abc)

[display m-exp, convert to s-exp and run it]
!,++?0'%#,'"(*a*b*c())

expression  (!(,(+(+(?0('(%))(#(,('(*a*b*c())))))))))
display     (*a*b*c())
display     (*a(*b(*c())))
value       (abc)


!++?0'%#~'"( [begin literally]

[ | = |x| = size of s-expression x in characters ]
:(|x) /=x()'{2} /.x'{1} ^(|+x)(|-x)

[ E = examine list x for element that is more than n characters in size. ]
[ If not found returns false/0. ]
:(Exn) /.x0 /(<n(|+x))+x (E-xn)

[ < = unary number x is less than unary number y ]
[ x and y are lists of 1's ]
:(<xy) /.y0 /.x1 (<-x-y)

[ (2n) = convert reversed binary to unary ]
:(2n) /.n() :k(2-n) /+n *1^kk ^kk

[ Here we are given the formal axiomatic system FAS. ]
:f '"("?)  [insert FAS m-expression here inside ()]

[ n = the number of characters in program including the FAS. ]
:n ~^(|f)(2'(110 111 01)) [show that this m-exp knows its own size]
[ n = 187 base 10 + |FAS| = 273 base 8 + |FAS| ]

[ L = loop running the formal axiomatic system ]
:(Lt)
  :v ?t'!%#f    [Run the formal system for t time steps.]
  :s (E-vn)     [Did it output an elegant m-exp larger than this program?]
  /s !++?0'%#s  [If found elegant m-exp bigger than this program,
                 run it so that its output is our output (contradiction!)]
  /.+v (L*1t)   [If not, keep looping]
  "?            [or halt if formal system halted.]
(L())           [Start loop running with t = 0.]

)               [end literally]

expression  (!(+(+(?0('(%))(#(~('(:(|x)/=x()'{2}/.x'{1}^(|+x)(
            |-x):(Exn)/.x0/(<n(|+x))+x(E-xn):(<xy)/.y0/.x1(<-x
            -y):(2n)/.n():k(2-n)/+n*1^kk^kk:f'"("?):n~^(|f)(2'
            (11011101)):(Lt):v?t'!%#f:s(E-vn)/s!++?0'%#s/.+v(L
            *1t)"?(L())))))))))
show        (:(|x)/=x()'{2}/.x'{1}^(|+x)(|-x):(Exn)/.x0/(<n(|+
            x))+x(E-xn):(<xy)/.y0/.x1(<-x-y):(2n)/.n():k(2-n)/
            +n*1^kk^kk:f'"("?):n~^(|f)(2'(11011101)):(Lt):v?t'
            !%#f:s(E-vn)/s!++?0'%#s/.+v(L*1t)"?(L()))
size        189(275)/1323(2453)
show        (1111111111111111111111111111111111111111111111111
            11111111111111111111111111111111111111111111111111
            11111111111111111111111111111111111111111111111111
            111111111111111111111111111111111111111111)
size        191(277)/1337(2471)
value       ?

End of LISP Run

Elapsed time is 0 seconds.
